/**
 * HDR capturing example (GoPro Hero 4, 5, and 6).
 * Author: Camera Controller
 * Web: http://www.tequnique.com/cameracontroller
 * Description: This example shows how to capture exposure series (e.g. for HDR). below).
 */

// Helper function for capturing an image with a specific exposure
function captureImage(cameraName, exposureCommand) {
    // Set exposure
    var result = sendCustomCameraCommand(cameraName, exposureCommand);
    if (!result.ok) {
        logMessage("Error setting exposure: " + result.message, true);
    }

    // Capture photo
    result = startRecording(cameraName);
    if (!result.ok) {
        logMessage("Error capturing photo: " + result.message, true);
    }
}

// Use the currently connected camera:
var connectResult = connectToCamera();
if (connectResult.ok) {
    var cameraName = connectResult.message;

    // Change the camera mode to 4 (which is photo mode on the GoPro Hero 4, 5, 6). The index
    // depends on the camera model.
    var result = changeCameraMode(cameraName, 4);
    if (!result.ok) {
        logMessage("Error changing camera mode to photo: " + result.message, true);
    }

    // Give the camera some time for changing the mode
    waitMilliseconds(500);

    // Log the current camera mode
    var cameraModeIndex = getCurrentCameraMode(cameraName);
    logMessage("The current camera mode is: " + cameraModeIndex);

    // Enable Protune
    result = sendCustomCameraCommand(cameraName, "/setting/21/1");
    if (!result.ok) {
        logMessage("Error enabling Protune: " + result.message, true);
    }

    // Capture three images with different exposures
    captureImage(cameraName, "/setting/26/8"); // 1
    waitMilliseconds(2000); // give the camera some time for capturing

    captureImage(cameraName, "/setting/26/4"); // 2
    waitMilliseconds(2000); // give the camera some time for capturing

    captureImage(cameraName, "/setting/26/0"); // 3
    logMessage("Done");
}
else logMessage("No camera found");

